red <- paste("<font color=\"red\">")
library(ggplot2)
source("myround.r")

qqplot.data <- function (vec) # argument: vector of numbers
{
  # following four lines from base R's qqline()
  y <- quantile(vec[!is.na(vec)], c(0.25, 0.75))
  x <- qnorm(c(0.25, 0.75))
  slope <- diff(y)/diff(x)
  int <- y[1L] - slope * x[1L]

  d <- data.frame(resids = vec)

  ggplot(d, aes(sample = resids)) + stat_qq() + geom_abline(slope = slope, intercept = int)

}
shinyServer(function(input, output) {

    data <- reactive({ 
        source("clipboard")
        y <- A$y
        yvals <- unique(y)
        if(is.na(A$catVarOrder)) catVarOrder<-yvals
        else catVarOrder<-A$catVarOrder
        list(x=A$x,y=factor(y,levels=yvals),m=length(yvals),catVarOrder=catVarOrder,xname=A$xname,yname=A$yname)
    })             
 
   output$text1 <- renderText({
        x <- data()$x
        m <- data()$m
        y <- data()$y
        catVarOrder <- data()$catVarOrder
        txt <- rep("",m)
        for(i in 1:m) {
              txt[i] <- paste("<h5>",data()$yname," = ",catVarOrder[i],"</h5>")
              x1 <- x[y==catVarOrder[i]]
              if(input$ord=="Yes") x1 <- sort(x1)
              if(length(x1)<=50) txt[i] <- paste(txt[i],"<h5>",paste(x1,collapse=" "),"</h5>")
              else txt[i] <- paste(txt[i],"<h5>",paste(x1[1:25],collapse=" "),
                                  "<br>...<br>",paste(x1[(length(x1)-24):length(x1)],collapse=" "),"</h5>")                      
       }     
       c(txt,"<hr>") 
        
   })   
   output$text2 <- renderText({
        x <- data()$x
        m <- data()$m
        y <- data()$y
        catVarOrder <- data()$catVarOrder
        z <- as.list(1:m)
        names(z) <- catVarOrder
        for(i in 1:m) z[[i]]<-x[y==catVarOrder[i]]
        a <- paste("<h4>Summary Statistics for",data()$xname,":</h4>")
        tbl <- paste("<tr><td>&nbsp;</td>",paste("<th>",catVarOrder,"</th>",collapse=""),"</tr>")
        if("Sample Size" %in% input$which) {
               s <-paste("<td>",unlist(lapply(z,length)),"</td>",collapse="")
               tbl <- c(tbl,paste("<tr><th>Sample Size: </th>",s,"</tr>"))    
        }  
        if("Mean" %in% input$which) {
               s <-paste("<td>",unlist(lapply(z,myround,fun=mean)),"</td>",collapse="")
               tbl <- c(tbl,paste("<tr><th>Mean: </th>",s,"</tr>"))    
        }
        if("Median" %in% input$which) {
               s <-paste("<td>",unlist(lapply(z,myround,fun=median)),"</td>",collapse="")
               tbl <- c(tbl,paste("<tr><th>Median: </th>",s,"</tr>"))    
        }
        if("Standard Deviation" %in% input$which) {
               s <-paste("<td>",unlist(lapply(z,myround,fun=sd)),"</td>",collapse="")
               tbl <- c(tbl,paste("<tr><th>Standard Deviation: </th>",s,"</tr>"))    
        }
        if("First Quartile" %in% input$which)  {
               s <-paste("<td>",unlist(lapply(z,myround,fun=quantile,p=0.25)),"</td>",collapse="")
               tbl <- c(tbl,paste("<tr><th>First Quartile: </th>",s,"</tr>"))    
        }
        if("Third Quartile" %in% input$which) {
               s <-paste("<td>",unlist(lapply(z,myround,fun=quantile,p=0.75)),"</td>",collapse="")
               tbl <- c(tbl,paste("<tr><th>Third Quartile: </th>",s,"</tr>"))    
        }
        if("Interquartile Range" %in% input$which) {
               s <-paste("<td>",unlist(lapply(z,myround,fun=IQR)),"</td>",collapse="")
               tbl <- c(tbl,paste("<tr><th>IQR: </th>",s,"</tr>"))    
        }

          a <- c(a,"<table>",tbl,"</table>")
   
   })       
   
   output$plot <- renderPlot({
          dta <- data.frame(x=data()$x,y=data()$y)
          plt <- ggplot(data=dta,aes(y,x))+ 
                  geom_boxplot()+ylab("")+xlab(data()$yname)
          if(input$doPrint=="pdf") {
                pdf("c:/R/output/graph.pdf")
                print(plt)
                dev.off()
          }          
          if(input$doPrint=="png") {
                png("c:/R/output/graph.png")
                print(plt)
                dev.off()
          }          
          plt
   })

   output$appinfo <- renderText({ 
      HTML("<br>&nbsp;<br>&nbsp;<br>&nbsp;<br>
      <a target=\"_blank\" href=\"http://academic.uprm.edu/wrolke/myapps1.htm#none\"><h4>What to do</h4></a><br>
      <h6>Written by: Dr. Wolfgang Rolke<br>Created: 2/22/2016</h6>")
      
  })       

})

